@@ -1,29 +1,20 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
-from __future__ import absolute_import
-
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from traits.api import (
-    Float,
     HasTraits,
     Int,
-    ReadOnly,
     Str,
     TraitError,
-    Undefined,
 )
 
 
@@ -84,9 +75,3 @@ class GetTraitTestCase(unittest.TestCase):
         self.assertIn("baz", dir(b))
         self.assertIn("num", dir(b))
         self.assertIn("edit_traits", dir(b))
-
-
-### EOF #######################################################################
-
-if __name__ == "__main__":
-    unittest.main()
